{% extends changelist_template_parent %}
{% load static %}


{% block extrahead %}
    {{block.super}}
    {% if is_popup %}
        {% include "admin/cms/scripts.html" %}
        <script>
            $(function(){
                django.jQuery.cms.media.initBrowser();
            });
        </script>
    {% endif %}
{% endblock %}
